@@ -148,8 +148,13 @@ class Kitchen(arcade.Window):
         s.center_y = y
         self.miscs.append(s)
 
-    def set_end(self, text, c=arcade.color.RED, s=48):
+    def set_end(self, text, c='red', s=48):
         self.end_text = text
+        c = str.upper(c)
+        if c in dir(arcade.color):
+            c = getattr(arcade.color, c)
+        else:
+            c = arcade.color.RED
         self.end_color = c
         self.end_size = s
 
